/*!
 * jQuery onAction Plugin v1.0
 * http://outwestmedia.com/jquery-refactored/
 *
 * Released: 2009-09-13
 * Version: 1.0
 *
 * Copyright (c) 2009 Jonathan Sharp, Out West Media LLC.
 * Dual licensed under the MIT and GPL licenses.
 * http://docs.jquery.com/License
 */
(function($) {
	// Global event listener using event delegation. This captures click
	// events and dispatches custom events based upon class. This pattern 
	// is slightly different than $().live()
	$(document)
		.bind('click', function(evt) {
			var ret = true;
			// Construct a group of elements (target, parents) and walk 
			// through the elements looking for the first action-* class
			$([])
				.add(evt.target)
				.add( $(evt.target).parents() )
				.each(function() {
					var action = this.className.match(/(^|\s)(action-[^\s]+)(\s|$)/);
					if ( action ) {
						var type = action[2].replace(/[^a-z0-9]/g, '').toLowerCase();
						$(this).trigger(type, [evt.target]);
						ret = false;
						return false;
					}
				});
			// Do not cancel click events on the checkbox
			if ( !$(evt.target).is(':checkbox') ) {
				return ret;
			}
		});
	
	// Callback and action handlers
	$.onAction = function(action, callback) {
		var split = action.split(/\s+/);
		for (var i = 0; i < split.length; i++ ) {
			var event = split[i];
			var type = 'action' + event.toLowerCase();
			$(document).bind(type, function(evt) {
				return callback.apply(evt.target, [evt]);
			});
		}
	};
})(jQuery);